The Foos and The Bars - A Developer

1. # A Limerick

       There was an old man from Nantucket
       Who kept all his cash in a bucket,
       His daughter, called Nan, ran away with a man,
       And as for the bucket - Nantucket!

2. # A Series of unfortunate blogs

   I woke up this morning to discover that I had turned into a rather large root vegetable, possibly a turnip or parsnip, it was hard to tell.

   ## What happened next

   Reader, they pureed me!

3. # I Use This

   A while back, I published a post about my setup, inspired by the awesome articles on the UsesThis site.

   As times change, so does my toolset. So, here's a list of my latest favorite things. I love them, and think you should use them too.

   ## ep.io

   Perfectly Pythonic ...

   Read more

4. # New Blog: Finally Static!

   I've been wanting to convert my website from a WordPress-powered application to a static one for a long time now. I tried a few different systems, but nothing was flexible enough for my needs.

   I almost sat down and wrote something myself, but luckly I found Alex Metaireau's ...

   Read more

5. # Static Sites on Heroku Cedar

   Heroku's excellent Cedar Stack has first-class support for Python, Ruby, Node.js, Java, Clojure, and Scala applications. Unfortunately, there's no obvious way to serve static sites without first fronting them with a Rack or WSGI application.

   The Cedar stack has unofficial support for Custom Build Packs, which allow ...

   Read more

6. # Unix Exit Status Code Reference

   I always find myself constantly Googling the list of unix status codes (typically defined in `sysexits.h`).

       0 # successful termination 64 # base value for error messages
       64 # command line usage error
       65 # data format error
       66 # cannot open input
       67 # addressee unknown
       68 # host name unknown
       69 # service unavailable
       70 ...

   Read more

## blogroll

- About
- Resume

## social

- atom feed
- GitHub
- Twitter